*********
Nengo SPA
*********

Nengo SPA is an implementation of the Semantic Pointer Architecture for Nengo.
The `Semantic Pointer Architecture
<http://compneuro.uwaterloo.ca/research/spa/semantic-pointer-architecture.html>`_
provides an approach to building cognitive models
implemented with large-scale spiking neural networks.


.. toctree::
   :maxdepth: 2

   getting_started
   user_guide
   examples
   api
   developer
